@@ -14,25 +14,27 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 from calculate.consolegui import qt
-import urllib2
+import urllib.request as urllib2
 
-from DisplayMethod import DisplayMethod, StartWidget, ConnectLostLabel
-from mainframe import MainFrame
-from mainmenu import MainMenu
-from ControlButton import MethodNameWgt, ControlButtonWgt
-from helpwidget import HelpWgt, BugWgt
-from tools import ToolsWidget
+from .DisplayMethod import DisplayMethod, StartWidget, ConnectLostLabel
+from .mainframe import MainFrame
+from .mainmenu import MainMenu
+from .ControlButton import MethodNameWgt, ControlButtonWgt
+from .helpwidget import HelpWgt, BugWgt
+from .tools import ToolsWidget
 
-from conf_connection import FrameConnection
-from LeftMenu import LeftMenu
-from MainFrameResult import MainFrameRes
-from View_Process import ViewProc
-from session_function import ViewSessionInfo
-from CertificateClass import CertClass
+from .conf_connection import FrameConnection
+from .LeftMenu import LeftMenu
+from .MainFrameResult import MainFrameRes
+from .View_Process import ViewProc
+from .session_function import ViewSessionInfo
+from .CertificateClass import CertClass
 
-from pid_information import client_list_pid
-from more import icon_visible, client_del_sid, show_msg, get_icon
+from .pid_information import client_list_pid
+from .more import icon_visible, client_del_sid, show_msg, get_icon
 
 DEBUG_LEVEL = 0
 
@@ -40,12 +42,12 @@ DEBUG_LEVEL = 0
 def debug(level, *args):
     if level <= DEBUG_LEVEL:
         for s in args:
-            print s,
-        print
+            print(s, end=' ')
+        print()
 
 class MainWgt(qt.QMainWindow):
     def __init__(self, ClientObj):
-        qt.QMainWindow.__init__(self)
+        super().__init__()
         self.ClientObj = ClientObj
         self.initUI()
 
@@ -162,7 +164,7 @@ class MainWgt(qt.QMainWindow):
         self.resize(self.cur_size)
 
     def back(self):
-        self.control_button.del_button()
+        # self.control_button.del_button()
         if len(self.ClientObj.back_step_list) < 2:
             self.delete_MainFrameWgt()
 
@@ -315,7 +317,7 @@ class MainWgt(qt.QMainWindow):
                 TempMainFrameWgt.analysis(meth_result)
             except (RuntimeError, ValueError):
                 pass
-            except urllib2.URLError, e:
+            except urllib2.URLError as e:
                 show_msg(e, 'URLError')
 
         else:
@@ -331,7 +333,7 @@ class MainWgt(qt.QMainWindow):
                 self.MainFrameWgt.analysis(meth_result)
             except (RuntimeError, ValueError):
                 pass
-            except urllib2.URLError, e:
+            except urllib2.URLError as e:
                 show_msg(e, 'URLError')
 
     def main_view_process(self, method_name, meth_result, pid):
@@ -343,17 +345,20 @@ class MainWgt(qt.QMainWindow):
 
         self.left_frame.hide()
 
-        try:
-            self.MainFrameWgt.get_entire_frame(pid)
-        except (RuntimeError, ValueError):
-            pass
+        #DEBUG
+
+        #check why are they here?
+        # try:
+        self.MainFrameWgt.get_entire_frame(pid)
+        # except (RuntimeError, ValueError):
+        #     pass
 
     def delete_MainFrameWgt(self):
         self.main_frame.takeWidget()
-        try:
-            self.MainFrameWgt.close()
-        except (RuntimeError, AttributeError):
-            pass
+        # try:
+        self.MainFrameWgt.close()
+        # except (RuntimeError, AttributeError):
+        #     pass
 
     def setScrollBarVal(self):
         self.main_frame.verticalScrollBar().setSliderPosition \
