@@ -14,16 +14,19 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from Box import MainWgt
+from __future__ import absolute_import
+from .Box import MainWgt
 from calculate.consolegui import qt
 #from mainmenu import MainMenu
 
 import os
-import ConfigParser
-
+# import ConfigParser
+import calculate.lib.configparser as ConfigParser
+import gettext
+_ = gettext.gettext
 class ApiClient(qt.QWidget):
     def __init__(self, app, tabs):
-        super(ApiClient, self).__init__()
+        super().__init__()
         self.app = app
         self._parent = tabs
 
@@ -90,11 +93,13 @@ class ApiClient(qt.QWidget):
 
         ###################### other ##########################
         import gettext
+        import locale
         # get language
         try:
             self.lang = config.get('other', 'lang')
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
-            default_locale = gettext.locale.getdefaultlocale()
+            # default_locale = gettext.locale.getdefaultlocale()
+            default_locale = locale.getdefaultlocale()
             if default_locale[0]:
                 self.lang = default_locale[0][:2]
             else:
@@ -110,7 +115,8 @@ class ApiClient(qt.QWidget):
             lang = gettext.translation('cl_consolegui3',languages=[],fallback=True)
 
         try:
-            lang.install(unicode=True)
+            lang.install()
+            # lang.install(unicode=True)
         except UnboundLocalError:
             pass
         try:
