@@ -14,23 +14,28 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from calculate.consolegui import qt
 import calculate.contrib
 from suds import WebFault
 import logging, OpenSSL
-import ConfigParser, os, urllib2
+import os
+import calculate.lib.configparser as ConfigParser
+import urllib.request as urllib2
 import getpass
 
-from calculate.core.client.function import clear as clear_suds_cache
-from session_function import client_post_cert
-from calculate.core.client.cert_verify import VerifyError
+# from calculate.core.client.function import clear as clear_suds_cache
+from .utils import clear as clear_suds_cache
+from .session_function import client_post_cert
+# from calculate.core.client.cert_verify import VerifyError
+from .client_class import VerifyError
 
-from client_class import Client_suds, HTTPSClientCertTransport
-from more import post_connect_action, show_msg, uniq, LabelWordWrap, get_icon, dpivalue
+from .client_class import Client_suds, HTTPSClientCertTransport
+from .more import post_connect_action, show_msg, uniq, LabelWordWrap, get_icon, dpivalue
 
 class LocalhostPasswd(qt.QDialog):
     def __init__(self, parent):
-        qt.QDialog.__init__(self)
+        super().__init__()
         grid = qt.QGridLayout(self)
         grid.setContentsMargins(10, 10, 10, 10)
         grid.setSpacing(4)
@@ -73,7 +78,7 @@ class LocalhostPasswd(qt.QDialog):
 
 class FrameConnection(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        qt.QWidget.__init__(self)
+        super().__init__()
         self.ClientObj = ClientObj
 
     def initUI(self, parent, window):
@@ -254,7 +259,7 @@ class FrameConnection(qt.QWidget):
         # not twice connect to localhost
         if host_name == 'localhost':
             host_name = '127.0.0.1'
-
+        # raise Exception
         if not port:
             port = self.ClientObj.VarsApi.GetInteger('core.cl_core_port')
 
@@ -275,20 +280,20 @@ class FrameConnection(qt.QWidget):
             pass
         path_to_cert = self.ClientObj.path_to_cert
         try:
-            client = Client_suds(url, transport = \
-                        HTTPSClientCertTransport(None,None, path_to_cert, \
+            client = Client_suds(url, transport =
+                        HTTPSClientCertTransport(None, None, path_to_cert,
                         parent = self.ClientObj, timeout = 10))
-        except AttributeError, e:
+        except AttributeError as e:
             show_msg (_('This server is not trusted'), _('Not connected!'))
             return 1
-        except Exception, e:
+        except Exception as e:
             show_msg (e, _("Not connected!"))
             return 1
         client.wsdl.services[0].setlocation(url)
 
         try:
             server_host_name = client.service.get_server_host_name()
-        except urllib2.URLError, e:
+        except urllib2.URLError as e:
             show_msg (e, _("Not connected!"))
             return 1
         except Exception as e:
@@ -302,9 +307,9 @@ class FrameConnection(qt.QWidget):
             passwd = None
         try:
             import glob
+            
             all_cert_list = glob.glob(path_to_cert + '*.crt')
             fit_cert_list = []
-        
             for client_cert_path in all_cert_list:
                 client_cert = client_cert_path.replace(path_to_cert, '')
                 client_cert_name = client_cert.replace('.crt', '')
@@ -313,29 +318,29 @@ class FrameConnection(qt.QWidget):
             fit_cert_list.sort(key = len)
             Connect_Error = 1
             crypto_Error = 0
+            
+            
             for i in range (0, len(fit_cert_list)):
                 cert_name = fit_cert_list.pop()
                 CERT_FILE = path_to_cert + cert_name + '.crt'
                 CERT_KEY = path_to_cert + cert_name + '.key'
-
                 # check passwd private_key
                 import M2Crypto
                 bio = M2Crypto.BIO.openfile(CERT_KEY)
-                rsa = M2Crypto.m2.rsa_read_key(bio._ptr(),lambda *unused: "")
+                rsa = M2Crypto.m2.rsa_read_key(bio._ptr(), lambda *unused: b"")
                 if re_passwd != False:
-                    self.str_passwd = re_passwd
+                    self.str_passwd = re_passwd#, "UTF-8"
                 if not rsa and not self.str_passwd and auto:
                     self.passwd_wgt = LocalhostPasswd(self)
                     passwd = self.passwd_wgt.text()
                     self.str_passwd = passwd if passwd else None
-
                 try:
 #                if True:
+                    passw = bytes(self.str_passwd, "UTF-8") if self.str_passwd else None
                     self.ClientObj.client = Client_suds(url,\
                             transport = HTTPSClientCertTransport(CERT_KEY, \
                             CERT_FILE, path_to_cert, parent = self.ClientObj, \
-                            timeout = 5, password = self.str_passwd))
-
+                            timeout = 5, password = passw))
                     self.ClientObj.client.wsdl.services[0].setlocation(url)
                     self.ClientObj.client.set_parameters \
                                 (path_to_cert, CERT_FILE, CERT_KEY)
@@ -343,15 +348,18 @@ class FrameConnection(qt.QWidget):
                     client_post_cert(self.ClientObj.client, \
                                      self.ClientObj.lang)
                     Connect_Error = 0
-                except VerifyError, e:
+                except VerifyError as e:
                     show_msg (e.value,_("Server certificate verification error"),self)
                     e.message = 'VerifyError'
                     Connect_Error = 1
-                except OpenSSL.crypto.Error, e:
+                except OpenSSL.crypto.Error as e:
+                    print("OPENSSL ERROR")
                     Connect_Error = 1
                     crypto_Error = 1
-                except Exception, e:
-                    Connect_Error = 1
+                # except Exception as e:
+                #     print("GENERAL ERROR")
+                #     print(e)
+                #     Connect_Error = 1
                 if Connect_Error == 0:
                     break
             #If the certificate file misses
@@ -363,7 +371,7 @@ class FrameConnection(qt.QWidget):
                                                   _('Connection Error'), self)
                     return
 #                self.close()
-                if not locals().has_key('e'):
+                if 'e' not in locals():
                     mess = _('You do not have a certificate. Please generate '
                              'a new request and get the new certificate from '
                              'the server.')
@@ -413,7 +421,7 @@ class FrameConnection(qt.QWidget):
 #            self.ClientObj._parent.connect_count_changed(1)
             post_connect_action(self.ClientObj.client, self.ClientObj)
     #----------------------------------------------------
-        except WebFault, f:
+        except WebFault as f:
             show_msg ("Exception: %s" %f)
             _print (f.fault)
         self.close()
